MessageLookup class

Inheritance
  • Object
  • MessageLookupByLibrary
  • MessageLookup

Constructors

MessageLookup()

Properties

hashCode → int
The hash code for this object.
no setterinherited
localeName → String
Subclasses should override this to return their locale, e.g. 'en_US'
no setteroverride
messages → Map<String, dynamic>
Subclasses should override this to return a list of their message implementations. In this class these are functions, but subclasses may implement them differently.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluateMessage(Object? translation, List args) → String?
Evaluate the translated message and return the translated string.
inherited
lookupMessage(String? messageText, String? locale, String? name, List<Object>? args, String? meaning, {MessageIfAbsent? ifAbsent}) → String?
Return the localized version of a message. We are passed the original version of the message, which consists of a messageText that will be translated, and which may be interpolated based on one or more variables.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String messageName) → Object?
Return our message with the given name
inherited

Static Methods

m0(dynamic amount) → dynamic
m1(dynamic amount) → dynamic
m10(dynamic amount) → dynamic
m11(dynamic amount) → dynamic
m12(dynamic amount) → dynamic
m13(dynamic amount) → dynamic
m14(dynamic amount) → dynamic
m15(dynamic amount) → dynamic
m16(dynamic amount) → dynamic
m17(dynamic amount) → dynamic
m18(dynamic amount) → dynamic
m2(dynamic amount) → dynamic
m3(dynamic amount) → dynamic
m4(dynamic amount) → dynamic
m5(dynamic amount) → dynamic
m6(dynamic amount) → dynamic
m7(dynamic amount) → dynamic
m8(dynamic amount) → dynamic
m9(dynamic amount) → dynamic